@@ -28,7 +28,8 @@ ranarr[::2] = missing_value
 ranarr2[::2] = missing_value2
 NP.seterr(invalid='ignore') # silence warnings from ma.masked_values
 maskedarr = ma.masked_values(ranarr,missing_value)
-maskedarr2 = ma.masked_values(ranarr2,missing_value2)
+#maskedarr2 = ma.masked_values(ranarr2,missing_value2)
+maskedarr2 = ma.masked_invalid(ranarr2)
 scale_factor = (packeddata.max()-packeddata.min())/(2.*32766.)
 add_offset = 0.5*(packeddata.max()+packeddata.min())
 packeddata2 = NP.around((packeddata-add_offset)/scale_factor).astype('i2')
@@ -61,6 +62,13 @@ class PrimitiveTypesTestCase(unittest.TestCase):
         doh.scale_factor = 0.1
         doh.add_offset = 0.
         doh[0] = 1.1
+        # added to test fix to issue 381
+        doh2 = file.createVariable('packeddata3','i2','n')
+        doh2.add_offset = 1.
+        doh2[0] = 1.
+        # added test for issue 515
+        file.createDimension('x',1)
+        v = file.createVariable('v',NP.float,'x',fill_value=-9999)
         file.close()
 
     def tearDown(self):
@@ -75,6 +83,7 @@ class PrimitiveTypesTestCase(unittest.TestCase):
         datamasked3 = file.variables['maskeddata3']
         datapacked = file.variables['packeddata']
         datapacked2 = file.variables['packeddata2']
+        datapacked3 = file.variables['packeddata3']
         # check missing_value, scale_factor and add_offset attributes.
         assert datamasked.missing_value == missing_value
         assert datapacked.scale_factor == scale_factor
@@ -95,8 +104,11 @@ class PrimitiveTypesTestCase(unittest.TestCase):
         assert_array_almost_equal(datamasked[:].filled(),ranarr)
         assert_array_almost_equal(datamasked2[:].filled(),ranarr2)
         assert_array_almost_equal(datapacked[:],packeddata,decimal=4)
+        assert(datapacked3[:].dtype == NP.float)
         # added to test fix to issue 46 (result before r865 was 10)
         assert_array_equal(datapacked2[0],11)
+        # added test for issue 515
+        assert(file['v'][0] is NP.ma.masked)
         file.close()
 
 if __name__ == '__main__':
